pystagram.graph_api.endpoints.hashtag_search package — pystagram 0.1 documentation

# pystagram.graph_api.endpoints.hashtag_search package

## Submodules

## pystagram.graph_api.endpoints.hashtag_search.hashtag_search module

class pystagram.graph_api.endpoints.hashtag_search.hashtag_search.HashtagSearch(graph_api: GraphInstagramBaseApi)

  Bases: `object`

  The HashtagSearch node of the Instagram Graph API.

  Parameters:

    graph_api (`InstagramGraphApi`) – An instance of the `InstagramGraphApi` class.

  get(q: str, user_id: str | None = None, access_token: str | None = None)

    Get the id of an Instagram hashtag. IDs are both static and global (i.e, the ID for #bluebottle will always be 17843857450040591 for all apps and all app users).

    Parameters:

      - q (str) – The hashtag to search for.

      - user_id (str, optional) – The ID of the Instagram user to get recent media from, inferred from the InstagramGraphApi instance if None, defaults to None

      - access_token (str, optional) – The access token of the Instagram user, inferred from the InstagramGraphApi instance if None, defaults to None

    Returns:

      The response from the GET /hashtag_search endpoint.

    Return type:

      `pystagram.helpers.api_client.api_response.InstagramApiResponse`

## Module contents